# GetIgnore3

<p align="center">😎 Get gitignore files without bothering yourself</p>

```
usage: getignore [-h] [-l] [-o] [template_name ...]

Get gitignore files without bothering yourself

positional arguments:
  template_name         Name(s) of gitignore templates to fetch
                        (e.g., Python, Node and etc.)

options:
  -h, --help            show this help message and exit
  -l, --list-templates  List available gitignore templates
  -o, --override        Override existing gitignore file instead of
                        appending
```

## Installation

- You either install it from `pypi` using `pip`:

```bash
pip install getignore3
```

- Or directly install it from `github` using `pip`:

```bash
pip install git+https://github.com/ashkanfeyzollahi/getignore3.git
```

- Or even build it from source!
